@@ -1,6 +1,6 @@
-use strict;
+use strict; use warnings;
 package Language::SNUSP;
-our $VERSION = '0.0.11';
+our $VERSION = '0.0.12';
 
 my $input = '';     # SNUSP input
 my $code = '';      # 2D code matrix
